summaryrefslogtreecommitdiffhomepage
path: root/packages/typescript-types
diff options
context:
space:
mode:
Diffstat (limited to 'packages/typescript-types')
-rw-r--r--packages/typescript-types/src/index.ts8
1 files changed, 4 insertions, 4 deletions
diff --git a/packages/typescript-types/src/index.ts b/packages/typescript-types/src/index.ts
index 4834a37..0fed2f8 100644
--- a/packages/typescript-types/src/index.ts
+++ b/packages/typescript-types/src/index.ts
@@ -55,7 +55,7 @@ export interface PublicKeyCredentialUserEntityJSON
/**
* The value returned from navigator.credentials.create()
*/
-export interface AttestationCredential extends PublicKeyCredential {
+export interface RegistrationCredential extends PublicKeyCredential {
response: AuthenticatorAttestationResponseFuture;
}
@@ -63,8 +63,8 @@ export interface AttestationCredential extends PublicKeyCredential {
* A slightly-modified AttestationCredential to simplify working with ArrayBuffers that
* are Base64URL-encoded in the browser so that they can be sent as JSON to the server.
*/
-export interface AttestationCredentialJSON
- extends Omit<AttestationCredential, 'response' | 'rawId' | 'getClientExtensionResults'> {
+export interface RegistrationCredentialJSON
+ extends Omit<RegistrationCredential, 'response' | 'rawId' | 'getClientExtensionResults'> {
rawId: Base64URLString;
response: AuthenticatorAttestationResponseJSON;
clientExtensionResults: AuthenticationExtensionsClientOutputs;
@@ -122,7 +122,7 @@ export type AuthenticatorDevice = {
credentialID: Buffer;
// Number of times this authenticator is expected to have been used
counter: number;
// From browser's `startAttestation()` -> AttestationCredentialJSON.transports (API L2 and up)
transports?: AuthenticatorTransport[];
};
@@ -122,7 +122,7 @@ export type AuthenticatorDevice = {
// Number of times this authenticator is expected to have been used
counter: number;
- // From browser's `startAttestation()` -> AttestationCredentialJSON.transports (API L2 and up)
+ // From browser's `startRegistration()` -> RegistrationCredentialJSON.transports (API L2 and up)
transports?: AuthenticatorTransport[];
};